import * as React from 'react'
import * as ReactDOM from 'react-dom'
import * as Sentry from '@sentry/browser'
import { I18nextProvider } from 'react-i18next'
import i18n from './Common/I18n'

import { MuiPickersUtilsProvider } from '@material-ui/pickers'
import DateFnsUtils from '@date-io/date-fns'

import { Auth0Service } from 'Auth/auth0-service'
import { Provider } from 'react-redux'
import { store } from './reducer'
import { App } from 'App'

export const auth0Service = Auth0Service

if (process.env.REACT_APP_SENTRY_DSN) {
  Sentry.init({
    dsn: process.env.REACT_APP_SENTRY_DSN,
    environment: process.env.REACT_APP_SENTRY_ENVIRONMENT,
  })
}

const rootEl = document.getElementById('root') as HTMLElement

ReactDOM.render(
  <I18nextProvider i18n={i18n}>
    <MuiPickersUtilsProvider utils={DateFnsUtils}>
      <Provider store={store}>
        <App />
      </Provider>
    </MuiPickersUtilsProvider>
  </I18nextProvider>,
  rootEl
)
